@@ -11,7 +11,18 @@
 
 #include <cstdarg>
 #include <cstring>
+
+#if __GNUC__ >= 12
+#pragma GCC diagnostic error "-Wmaybe-uninitialized"
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
 #include <functional>
+#pragma GCC diagnostic pop
+#pragma GCC diagnostic pop
+#else
+#include <functional>
+#endif
+
 #include <locale>
 #include <sstream>
 #include <string>
