@@ -13,11 +13,9 @@
 #define ELEKTRA_WRONG // make swig happy
 #endif
 
-#include <string>
-
-#include <key.hpp>
-
 #include <kdb.h>
+#include <key.hpp>
+#include <string>
 
 namespace kdb
 {
@@ -82,16 +80,6 @@ public:
 	ssize_t append (const Key & toAppend);
 	ssize_t append (const KeySet & toAppend);
 
-	Key head () const;
-	Key tail () const;
-
-	void rewind () const;
-	Key next () const;
-	Key current () const;
-
-	void setCursor (elektraCursor cursor) const;
-	elektraCursor getCursor () const;
-
 	Key pop ();
 	Key at (elektraCursor pos) const;
 
@@ -102,6 +90,9 @@ public:
 	template <typename T>
 	T get (std::string const & name, const elektraLookupFlags options = KDB_O_NONE) const;
 
+	ssize_t search (const Key & toSearch) const;
+	ssize_t search (std::string const & name) const;
+
 	// operators
 	inline bool operator== (const KeySet & ks) const;
 	inline bool operator!= (const KeySet & ks) const;
@@ -690,68 +681,6 @@ inline ssize_t KeySet::append (KeySet const & toAppend)
 	return ckdb::ksAppend (ks, toAppend.getKeySet ());
 }
 
-/**
- * @return alphabetical first key
- *
- * @copydoc ksHead()
- */
-inline Key KeySet::head () const
-{
-	return Key (ckdb::ksHead (ks));
-}
-
-/**
- * @return alphabetical last key
- *
- * @copydoc ksTail()
- */
-inline Key KeySet::tail () const
-{
-	return Key (ckdb::ksTail (ks));
-}
-
-
-/**
- * @copydoc ksRewind()
- */
-inline void KeySet::rewind () const
-{
-	ckdb::ksRewind (ks);
-}
-
-/**
- * @copydoc ksNext()
- */
-inline Key KeySet::next () const
-{
-	ckdb::Key * k = ckdb::ksNext (ks);
-	return Key (k);
-}
-
-/**
- * @copydoc ksCurrent()
- */
-inline Key KeySet::current () const
-{
-	return Key (ckdb::ksCurrent (ks));
-}
-
-/**
- * @copydoc ksSetCursor()
- */
-inline void KeySet::setCursor (elektraCursor cursor) const
-{
-	ckdb::ksSetCursor (ks, cursor);
-}
-
-/**
- * @copydoc ksGetCursor()
- */
-inline elektraCursor KeySet::getCursor () const
-{
-	return ckdb::ksGetCursor (ks);
-}
-
 /**
  * @copydoc ksPop()
  */
@@ -863,6 +792,25 @@ inline bool KeySet::operator!= (const KeySet & o) const
 }
 
 
+/**
+ * @copydoc ksSearch()
+ */
+inline ssize_t KeySet::search (const Key & toSearch) const
+{
+	return ckdb::ksSearch (ks, toSearch.getKey ());
+}
+
+/**
+ * @copydoc ksSearch()
+ *
+ * @note Accepts a keyname as string instead of a Key object.
+ */
+inline ssize_t KeySet::search (const std::string & name) const
+{
+	return search (Key (name));
+}
+
+
 } // end of namespace kdb
 
 #endif
