@@ -236,15 +236,6 @@ interface Elektra extends Library {
   // int keyGetRef (Pointer key);
 
   /* Meta Info */
-
-  int keyRewindMeta(Pointer key);
-
-  @Nullable
-  Pointer keyNextMeta(Pointer key);
-
-  @Nullable
-  Pointer keyCurrentMeta(Pointer key);
-
   int keyCopyMeta(Pointer dest, Pointer source, String metaName);
 
   int keyCopyAllMeta(Pointer dest, Pointer source);
@@ -252,11 +243,11 @@ interface Elektra extends Library {
   @Nullable
   Pointer keyGetMeta(Pointer key, String metaName);
 
-  int keySetMeta(Pointer key, String metaName, String newMetaString);
-
   @Nullable
   Pointer keyMeta(Pointer key);
 
+  int keySetMeta(Pointer key, String metaName, String newMetaString);
+
   /* Methods for Making Tests */
 
   int keyCmp(Pointer k1, Pointer k2);
