@@ -402,143 +402,3 @@ int keyIsString (const Key * key)
 
 	return keyGetMeta (key, "binary") == 0;
 }
-
-
-/**
- * @internal
- *
- * Compare 2 keys.
- *
- * The returned flags bit array has 1s (differ) or 0s (equal) for each key
- * meta info compared, that can be logically ORed using @c #elektraKeyFlags flags.
- * @link elektraKeyFlags::KEY_NAME KEY_NAME @endlink,
- * @link elektraKeyFlags::KEY_VALUE KEY_VALUE @endlink,
- * @link elektraKeyFlags::KEY_COMMENT KEY_COMMENT @endlink,
- * @link elektraKeyFlags::KEY_META KEY_META @endlink (will be set in addition to owner and comment),
- *
- * @par A very simple example would be
- * @code
- Key *key1, *key;
- uint32_t changes;
-
-// omited key1 and key2 initialization and manipulation
-
-changes=keyCompare(key1,key2);
-
-if (changes == 0) printf("key1 and key2 are identicall\n");
-
-if (changes & KEY_VALUE)
-printf("key1 and key2 have different values\n");
-
- *
- * @endcode
- *
- *
- * @par Example of very powerful specific Key lookup in a KeySet:
- * @code
- Key *base = keyNew ("/sw/MyApp/something", KEY_END);
- KDB *handle = kdbOpen(base);
- KeySet *ks=ksNew(0, KS_END);
- Key *current;
- uint32_t match;
- uint32_t interests;
-
-
- kdbGet(handle, ks, base);
-
-// we are interested only in name and/or value
-interests=(KEY_NAME | KEY_VALUE);
-
-ksRewind(ks);
-while ((current=ksNext(ks))) {
-match=keyCompare(current,base);
-
-if ((~match & interests) == interests) {
-printf("Key %s has same name, value, and sync status
-of base key",keyName(current));
-}
-// continue walking in the KeySet....
-}
-
-ksDel(ks);
-kdbClose (handle, base);
-keyDel(base);
-* @endcode
-*
-* @return a bit array pointing the differences
-* @param key1 first key
-* @param key2 second key
-* @see #elektraKeyFlags
-* @ingroup keytest
-	*/
-elektraKeyFlags keyCompare (const Key * key1, const Key * key2)
-{
-	if (!key1 && !key2) return 0;
-	if (!key1 || !key2) return KEY_NULL;
-
-	elektraKeyFlags ret = 0;
-	ssize_t nsize1 = keyGetNameSize (key1);
-	ssize_t nsize2 = keyGetNameSize (key2);
-	const char * name1 = keyName (key1);
-	const char * name2 = keyName (key2);
-	const Key * comment1 = keyGetMeta (key1, "comment");
-	const Key * comment2 = keyGetMeta (key2, "comment");
-	const void * value1 = keyValue (key1);
-	const void * value2 = keyValue (key2);
-	ssize_t size1 = keyGetValueSize (key1);
-	ssize_t size2 = keyGetValueSize (key2);
-
-	// TODO: might be (binary) by chance
-	if (strcmp (keyString (comment1), keyString (comment2))) ret |= KEY_COMMENT;
-
-	if (keyCompareMeta (key1, key2)) ret |= KEY_META;
-
-	if (nsize1 != nsize2)
-		ret |= KEY_NAME;
-	else if (!name1 || !name2)
-		ret |= KEY_NAME;
-	else if (strcmp (name1, name2))
-		ret |= KEY_NAME;
-
-
-	if (size1 != size2)
-		ret |= KEY_VALUE;
-	else if (!value1 || !value2)
-		ret |= KEY_VALUE;
-	else if (memcmp (value1, value2, size1))
-		ret |= KEY_VALUE;
-
-	// TODO: rewind metadata to previous position
-	return ret;
-}
-
-/**
- * @brief Compares metadata of two keys
- *
- * @retval KEY_META if there is a difference
- * @retval 0 if metadata is identical
- */
-int keyCompareMeta (const Key * k1, const Key * k2)
-{
-	const Key * meta1;
-
-	Key * key1 = (Key *) k1;
-	Key * key2 = (Key *) k2;
-
-	keyRewindMeta (key1);
-	keyRewindMeta (key2);
-	while ((meta1 = keyNextMeta (key1)) != 0)
-	{
-		const Key * meta2 = keyNextMeta (key2);
-		if (!meta2)
-		{
-			return KEY_META;
-		}
-
-		if (strcmp (keyName (meta1), keyName (meta2))) return KEY_META;
-		if (strcmp (keyString (meta1), keyString (meta2))) return KEY_META;
-	}
-
-	// TODO: rewind metadata to previous position
-	return 0;
-}
