@@ -23,10 +23,6 @@
 #include <stdlib.h>
 #endif
 
-#if DEBUG && defined(HAVE_STDIO_H)
-#include <stdio.h>
-#endif
-
 #include "kdbprivate.h"
 
 
@@ -120,12 +116,11 @@ keyDel(key);
  * @code
 KDB *handle = kdbOpen();
 KeySet *ks=ksNew(0, KS_END);
-Key *current=0;
-
 kdbGetByName(handle,ks,"system:/sw/my",KDB_O_SORT|KDB_O_RECURSIVE);
 
-ksRewind(ks);
-while (current=ksNext(ks)) {
+ for (elektraCursor it = 0; it < ksGetSize (ks); ++it)
+ {
+	Key * current = ksAtCursor (ks, it);
 	size_t size=0;
 
 	if (keyIsBinary(current)) {
