@@ -10,9 +10,7 @@
 #include "kdbconfig.h"
 #endif
 
-#if DEBUG && defined(HAVE_STDIO_H)
 #include <stdio.h>
-#endif
 
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
@@ -26,10 +24,6 @@
 #include <string.h>
 #endif
 
-#ifdef HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
 #include <kdbassert.h>
 
 #include "kdbinternal.h"
@@ -374,7 +368,7 @@ int mountGlobals (KDB * kdb, KeySet * keys, KeySet * modules, Key * errorKey)
 		KeySet * tmp = keys;
 		keys = elektraDefaultGlobalConfig (keys);
 		ksDel (tmp);
-		root = ksHead (keys);
+		root = ksAtCursor (keys, 0);
 	}
 	memset (kdb->globalPlugins, 0, NR_GLOBAL_POSITIONS * NR_GLOBAL_SUBPOSITIONS * sizeof (Plugin *));
 
@@ -392,9 +386,9 @@ int mountGlobals (KDB * kdb, KeySet * keys, KeySet * modules, Key * errorKey)
 		{
 			if (!elektraStrCaseCmp (placement, GlobalpluginPositionsStr[i]))
 			{
-#if DEBUG && VERBOSE
-				printf ("mounting global plugin %s to %s\n", pluginName, placement);
-#endif
+
+				ELEKTRA_LOG_DEBUG ("mounting global plugin %s to %s\n", keyString (cur), placement);
+
 				// load plugins in implicit max once placement
 				Plugin * plugin = 0;
 				int mountRet =
@@ -428,7 +422,7 @@ int mountGlobals (KDB * kdb, KeySet * keys, KeySet * modules, Key * errorKey)
 						if (!elektraStrCaseCmp (subPlacement, GlobalpluginSubPositionsStr[j]))
 						{
 							Plugin * subPlugin = 0;
-							int subRet =
+							int subRet = // makes ksCut on Keyset `global`!
 								elektraMountGlobalsLoadPlugin (&subPlugin, referencePlugins, curSubPosition,
 											       subPositions, system, modules, errorKey);
 							if (subRet == -1)
@@ -468,7 +462,6 @@ int mountGlobals (KDB * kdb, KeySet * keys, KeySet * modules, Key * errorKey)
 int mountModules (KDB * kdb, KeySet * modules, Key * errorKey)
 {
 	Key * root;
-	Key * cur;
 
 	root = ksLookupByName (modules, "system:/elektra/modules", 0);
 
@@ -481,9 +474,9 @@ int mountModules (KDB * kdb, KeySet * modules, Key * errorKey)
 	KeySet * alreadyMounted = ksNew (5, KS_END);
 	ssize_t oldSize = 0;
 
-	while ((cur = ksNext (modules)) != 0)
+	for (elektraCursor it = ksSearch (modules, root) + 1; it < ksGetSize (modules); ++it)
 	{
-		Backend * backend = backendOpenModules (modules, kdb->global, errorKey);
+		Backend * backend = backendOpenModules (modules, kdb->global, errorKey, it);
 
 		if (!backend)
 		{
