@@ -24,7 +24,7 @@
 #include <fcntl.h>     // access()
 #include <ftw.h>       // nftw()
 #include <stdint.h>    // nftw()
-#include <stdio.h>     // rename(), sprintf()
+#include <stdio.h>     // rename(), snprintf()
 #include <stdlib.h>    // nftw(), getenv()
 #include <string.h>    // nftw()
 #include <sys/stat.h>  // elektraMkdirParents
@@ -172,18 +172,18 @@ static int elektraMkdirParents (const char * pathname)
 static char * elektraGenTempFilename (char * cacheFileName)
 {
 	char * tmpFile = NULL;
-	size_t len = 0;
 	size_t tmpFilenameSize = 0;
 
 	size_t cacheFileNameSize = strlen (cacheFileName);
 	tmpFilenameSize = cacheFileNameSize + POSTFIX_SIZE;
 	tmpFile = elektraCalloc (tmpFilenameSize);
-	len = snprintf (tmpFile, cacheFileNameSize + 1, "%s", cacheFileName);
+	strncpy (tmpFile, cacheFileName, cacheFileNameSize + 1);
 
 	struct timeval tv;
 	memset (&tv, 0, sizeof (struct timeval));
 	gettimeofday (&tv, 0);
-	snprintf (tmpFile + len, POSTFIX_SIZE - 1, ".%d:%ld." ELEKTRA_TIME_USEC_F ".tmp", getpid (), tv.tv_sec, tv.tv_usec);
+	snprintf (tmpFile + cacheFileNameSize, tmpFilenameSize - cacheFileNameSize, ".%d:%ld." ELEKTRA_TIME_USEC_F ".tmp", getpid (),
+		  tv.tv_sec, tv.tv_usec);
 	return tmpFile;
 }
 
