@@ -12,11 +12,13 @@ ksNew (16,
 	KEY_END),
 	keyNew (PREFIX "/b",
 		KEY_VALUE, "hello",
+		KEY_META, "tomltype", "string_basic",
 		KEY_META, "type", "string",
 		KEY_META, "order", "2",
 	KEY_END),
 	keyNew (PREFIX "/c",
 		KEY_VALUE, "hello2",
+		KEY_META, "tomltype", "string_literal",
 		KEY_META, "type", "string",
 		KEY_META, "order", "3",
 	KEY_END),
@@ -42,6 +44,7 @@ ksNew (16,
 	KEY_END),
 	keyNew (PREFIX "/3/14",
 		KEY_VALUE, "PI",
+		KEY_META, "tomltype", "string_basic",
 		KEY_META, "type", "string",
 		KEY_META, "order", "8",
 	KEY_END),
