@@ -34,25 +34,24 @@ int SetCommand::execute (Cmdline const & cl)
 	KeySet conf;
 	Key k = cl.createKey (0);
 	std::string name = k.getName ();
+	Key parentKey = cl.getParentKey (k);
 
 	// do not resume on any get errors
 	// otherwise the user might break
 	// the config
-	kdb.get (conf, k);
+	kdb.get (conf, parentKey);
 
-	if (name[0] == '/')
-	{
-		// fix name for lookup
-		name = cl.ns + name;
-		if (!cl.quiet) std::cout << "Using name " << name << std::endl;
-
-		// fix k for kdb.set later
-		k.setName (name);
-	}
+	bool cascadingWrite = name[0] == '/';
 
 	Key key = conf.lookup (name);
 
 	std::ostringstream toprint;
+
+	if (!key && cascadingWrite)
+	{
+		cerr << "Aborting: A cascading write to a non-existent key is ambiguous." << endl;
+		return 2;
+	}
 	if (!key)
 	{
 		toprint << "Create a new key " << name;
@@ -72,10 +71,11 @@ int SetCommand::execute (Cmdline const & cl)
 		toprint << "Set string to \"" << value << '"' << endl;
 		key.setString (value);
 	}
-	kdb.set (conf, k);
-	printWarnings (cerr, k, cl.verbose, cl.debug);
-	printError (cerr, k, cl.verbose, cl.debug);
+	kdb.set (conf, parentKey);
+	printWarnings (cerr, parentKey, cl.verbose, cl.debug);
+	printError (cerr, parentKey, cl.verbose, cl.debug);
 
+	if (cascadingWrite) toprint << "Using name " << key.getName () << std::endl;
 	if (!cl.quiet) cout << toprint.str ();
 
 	return 0;
