@@ -45,6 +45,8 @@ extern gid_t nbGid;
 extern char * tempHome;
 extern int tempHomeLen;
 
+extern char * tmpfilename;
+
 int init (int argc, char ** argv);
 
 #ifndef __cplusplus
@@ -70,6 +72,12 @@ int init (int argc, char ** argv);
 		printf ("%s:%d: error in %s: %s\n", __FILE__, __LINE__, __func__, message);                                                \
 	}
 
+#define yield_error_fmt(message_fmt, ...)                                                                                                  \
+	{                                                                                                                                  \
+		nbError++;                                                                                                                 \
+		printf ("%s:%d: error in %s: " message_fmt "\n", __FILE__, __LINE__, __func__, __VA_ARGS__);                               \
+	}
+
 #define succeed_if(expression, message)                                                                                                    \
 	{                                                                                                                                  \
 		nbTest++;                                                                                                                  \
@@ -79,6 +87,15 @@ int init (int argc, char ** argv);
 		}                                                                                                                          \
 	}
 
+#define succeed_if_fmt(expression, message_fmt, ...)                                                                                       \
+	{                                                                                                                                  \
+		nbTest++;                                                                                                                  \
+		if (!(expression))                                                                                                         \
+		{                                                                                                                          \
+			yield_error_fmt (message_fmt, __VA_ARGS__);                                                                        \
+		}                                                                                                                          \
+	}
+
 #define exit_if_fail(expression, message)                                                                                                  \
 	{                                                                                                                                  \
 		nbTest++;                                                                                                                  \
@@ -229,20 +246,18 @@ int init (int argc, char ** argv);
 		ELEKTRA_DIAG_STORE                                                                                                         \
 		ELEKTRA_DIAG_OFF (-Waddress)                                                                                               \
 		if (!s1)                                                                                                                   \
-			yield_error ("left hand side is null pointer") else if (!s2)                                                       \
-				yield_error ("right hand side is null pointer") else if (strcmp (s1, s2) != 0)                             \
-			{                                                                                                                  \
-				char errorMsg[BUFFER_LENGTH];                                                                              \
-                                                                                                                                           \
-				strcpy (errorMsg, "string \"");                                                                            \
-				strcat (errorMsg, s1);                                                                                     \
-				strcat (errorMsg, "\" is not equal to \"");                                                                \
-				strcat (errorMsg, s2);                                                                                     \
-				strcat (errorMsg, "\"");                                                                                   \
-                                                                                                                                           \
-				yield_error (errorMsg);                                                                                    \
-				printf ("%s", "\tcompared: " #ps1 " and " #ps2 "\n");                                                      \
-			}                                                                                                                  \
+		{                                                                                                                          \
+			yield_error ("left hand side is null pointer")                                                                     \
+		}                                                                                                                          \
+		else if (!s2)                                                                                                              \
+		{                                                                                                                          \
+			yield_error ("right hand side is null pointer")                                                                    \
+		}                                                                                                                          \
+		else                                                                                                                       \
+		{                                                                                                                          \
+			succeed_if_fmt (strcmp (s1, s2) == 0, "string \"%s\" is not equal to \"%s\"\n\tcompared: %s and %s", s1, s2, #ps1, \
+					#ps2)                                                                                              \
+		}                                                                                                                          \
 		ELEKTRA_DIAG_RESTORE                                                                                                       \
 	}
 
@@ -270,22 +285,35 @@ int init (int argc, char ** argv);
  *
  */
 #define compare_key(pk1, pk2)                                                                                                              \
+	do                                                                                                                                 \
 	{                                                                                                                                  \
 		nbTest++;                                                                                                                  \
 		Key * mmk1 = (Key *) pk1;                                                                                                  \
 		Key * mmk2 = (Key *) pk2;                                                                                                  \
-		if (mmk1 != mmk2)                                                                                                          \
+		if (mmk1 == mmk2)                                                                                                          \
+		{                                                                                                                          \
+			break; /* same pointer */                                                                                          \
+		}                                                                                                                          \
+		else if (mmk1 == NULL)                                                                                                     \
+		{                                                                                                                          \
+			yield_error ("first key is null, but second is not")                                                               \
+		}                                                                                                                          \
+		else if (mmk2 == NULL)                                                                                                     \
+		{                                                                                                                          \
+			yield_error ("second key is null, but first is not")                                                               \
+		}                                                                                                                          \
+		else if (mmk1 != mmk2)                                                                                                     \
 		{                                                                                                                          \
 			compare_key_name (mmk1, mmk2);                                                                                     \
-                                                                                                                                           \
 			compare_key_value (mmk1, mmk2);                                                                                    \
                                                                                                                                            \
-			const Key * meta;                                                                                                  \
-			keyRewindMeta (mmk1);                                                                                              \
-			keyRewindMeta (mmk2);                                                                                              \
-			while ((meta = keyNextMeta (mmk1)) != 0)                                                                           \
+			KeySet * metaKeys1 = keyMeta (mmk1);                                                                               \
+			KeySet * metaKeys2 = keyMeta (mmk2);                                                                               \
+			ssize_t itMeta = 0;                                                                                                \
+			for (; itMeta < ksGetSize (metaKeys1); ++itMeta)                                                                   \
 			{                                                                                                                  \
-				const Key * const metaCmp = keyNextMeta (mmk2);                                                            \
+				const Key * const meta = ksAtCursor (metaKeys1, itMeta);                                                   \
+				const Key * const metaCmp = ksAtCursor (metaKeys2, itMeta);                                                \
 				if (metaCmp == 0)                                                                                          \
 				{                                                                                                          \
 					nbError++;                                                                                         \
@@ -312,7 +340,7 @@ int init (int argc, char ** argv);
 				}                                                                                                          \
 			}                                                                                                                  \
                                                                                                                                            \
-			const Key * const metaCmp = keyNextMeta (mmk2);                                                                    \
+			const Key * const metaCmp = ksAtCursor (metaKeys2, itMeta);                                                        \
 			if (metaCmp != 0)                                                                                                  \
 			{                                                                                                                  \
 				nbError++;                                                                                                 \
@@ -320,7 +348,7 @@ int init (int argc, char ** argv);
 					__FILE__, __LINE__, __func__, ELEKTRA_QUOTE (mmk1), ELEKTRA_QUOTE (mmk2));                         \
 			}                                                                                                                  \
 		}                                                                                                                          \
-	}
+	} while (0)
 
 
 /**Compare two keysets.
@@ -336,9 +364,6 @@ int init (int argc, char ** argv);
 		int bothEmpty = ksGetSize (mmks1) == 0 && ksGetSize (mmks1) == ksGetSize (mmks2);                                          \
 		if (mmks1 != mmks2 && !bothEmpty)                                                                                          \
 		{                                                                                                                          \
-			Key * cmmk1 = 0;                                                                                                   \
-			Key * cmmk2 = 0;                                                                                                   \
-                                                                                                                                           \
 			if (ksGetSize (mmks1) == 0) yield_error ("real size of " ELEKTRA_QUOTE (mmks1) " was 0");                          \
 			if (ksGetSize (mmks2) == 0) yield_error ("real size of " ELEKTRA_QUOTE (mmks2) " was 0");                          \
                                                                                                                                            \
@@ -356,13 +381,10 @@ int init (int argc, char ** argv);
 			}                                                                                                                  \
 			else                                                                                                               \
 			{                                                                                                                  \
-                                                                                                                                           \
-				ksRewind (mmks1);                                                                                          \
-				ksRewind (mmks2);                                                                                          \
-                                                                                                                                           \
-				while ((cmmk1 = ksNext (mmks1)) != 0)                                                                      \
+				for (elektraCursor it = 0; it < ksGetSize (mmks1); ++it)                                                   \
 				{                                                                                                          \
-					cmmk2 = ksNext (mmks2);                                                                            \
+					Key * cmmk1 = ksAtCursor (mmks1, it);                                                              \
+					Key * cmmk2 = ksAtCursor (mmks2, it);                                                              \
 					if (!cmmk2)                                                                                        \
 					{                                                                                                  \
 						yield_error ("Compare keyset " ELEKTRA_QUOTE (mmks1) " with " ELEKTRA_QUOTE (              \
@@ -382,6 +404,7 @@ int compare_line_files (const char * filename, const char * genfilename);
 int compare_regex_to_line_files (const char * filename, const char * genfilename);
 
 char * srcdir_file (const char * fileName);
+char * bindir_file (const char * fileName);
 const char * elektraFilename (void);
 void elektraUnlink (const char * filename);
 
