@@ -16,12 +16,12 @@
 static void test_keyRefcounter (void)
 {
 	Key * key = keyNew ("/", KEY_END);
-	key->ksReference = 5;
-	succeed_if (key->ksReference == 5, "wrong ref");
+	key->refs = 5;
+	succeed_if (key->refs == 5, "wrong ref");
 	succeed_if (keyGetRef (key) == 5, "wrong ref");
 	while (keyGetRef (key) > 0)
 		keyDecRef (key);
-	succeed_if (key->ksReference == 0, "wrong ref after dec");
+	succeed_if (key->refs == 0, "wrong ref after dec");
 	succeed_if (keyGetRef (key) == 0, "reference counter");
 	succeed_if (keyDecRef (key) == 0, "should stay at minimum");
 	succeed_if (keyGetRef (key) == 0, "reference counter");
@@ -228,34 +228,6 @@ static void test_keyNameUnescape (void)
 	}
 }
 
-static void test_keyCompare (void)
-{
-	printf ("test keyCompare\n");
-	Key * key1 = keyNew ("/", KEY_END);
-	Key * key2 = keyNew ("/", KEY_END);
-
-	succeed_if (keyCompare (key1, key2) == 0, "the keys don't differ of course");
-
-	keySetName (key1, "user:/myname");
-	succeed_if_same_string (keyName (key1), "user:/myname");
-	succeed_if (keyCompare (key1, key2) == KEY_NAME, "the keys should differ in name");
-	keySetName (key2, "user:/myname");
-	succeed_if (keyCompare (key1, key2) == 0, "the keys should not differ in name");
-
-	keySetString (key1, "myvalue");
-	succeed_if (keyCompare (key1, key2) == KEY_VALUE, "the keys should differ in value");
-	keySetString (key2, "myvalue");
-	succeed_if (keyCompare (key1, key2) == 0, "the keys should not differ in value");
-
-	keySetComment (key1, "mycomment");
-	succeed_if (keyCompare (key1, key2) == (KEY_COMMENT | KEY_META), "the keys should differ in comment");
-	keySetComment (key2, "mycomment");
-	succeed_if (keyCompare (key1, key2) == 0, "the keys should not differ in comment");
-
-	keyDel (key1);
-	keyDel (key2);
-}
-
 static void test_keyNewExtensions (void)
 {
 	printf ("test keyNewExtensions\n");
@@ -762,7 +734,6 @@ static void test_keyNeedSync (void)
 
 static void test_keyCopy (void)
 {
-	// FIXME: add more tests
 	printf ("test copy key\n");
 	Key * k = keyNew ("/", KEY_END);
 	Key * c = keyNew ("user:/name", KEY_END);
@@ -776,8 +747,75 @@ static void test_keyCopy (void)
 	succeed_if_same_string (keyName (k), "/abc");
 	succeed_if_same_string (keyName (c), "/abc");
 
+	succeed_if (keySetName (c, "spec:/test") != -1, "could not set name");
+	succeed_if (keyCopy (k, c, KEY_CP_NAME) != NULL, "could not copy");
+	succeed_if_same_string (keyName (k), "spec:/test");
+	succeed_if_same_string (keyName (c), "spec:/test");
+
+	succeed_if (keySetName (c, "proc:/test") != -1, "could not set name");
+	succeed_if (keyCopy (k, c, KEY_CP_NAME) != NULL, "could not copy");
+	succeed_if_same_string (keyName (k), "proc:/test");
+	succeed_if_same_string (keyName (c), "proc:/test");
+
+	succeed_if (keyCopy (k, c, KEY_CP_VALUE | KEY_CP_STRING) == NULL, "could copy despite of illegal flags");
+
 	keyDel (k);
 	keyDel (c);
+
+	Key * keyLock = keyNew ("user:/foo", KEY_FLAGS, KEY_LOCK_NAME | KEY_LOCK_VALUE | KEY_LOCK_META, KEY_END);
+	Key * keyNorm = keyNew ("user:/test", KEY_END);
+
+	succeed_if (keyCopy (keyNorm, keyLock, KEY_CP_NAME) != NULL, "could not copy");
+	succeed_if_same_string (keyName (keyNorm), "user:/foo");
+	succeed_if_same_string (keyName (keyLock), "user:/foo");
+
+	succeed_if (keySetName (keyNorm, "user:/test") != -1, "could not set name");
+	succeed_if (keyCopy (keyLock, keyNorm, KEY_CP_NAME) == NULL, "could copy locked key");
+	succeed_if_same_string (keyName (keyNorm), "user:/test");
+	succeed_if_same_string (keyName (keyLock), "user:/foo");
+
+	succeed_if (keyCopy (NULL, keyNorm, KEY_CP_NAME) == NULL, "could copy to NULL");
+	succeed_if (keyCopy (NULL, keyLock, KEY_CP_NAME) == NULL, "could copy to NULL");
+	succeed_if_same_string (keyName (keyNorm), "user:/test");
+	succeed_if_same_string (keyName (keyLock), "user:/foo");
+
+	Key * keyBin = keyNew ("user:/binary/foo", KEY_FLAGS, KEY_BINARY, KEY_END);
+	succeed_if (keyIsBinary (keyBin), "error creating binary key");
+
+	keySetString (keyNorm, "This is a string");
+	succeed_if_same_string (keyString (keyNorm), "This is a string");
+
+	succeed_if (keyCopy (keyNorm, keyBin, KEY_CP_STRING) == NULL, "could copy string to binary key");
+	succeed_if_same_string (keyName (keyNorm), "user:/test");
+	succeed_if_same_string (keyString (keyNorm), "This is a string");
+	succeed_if_same_string (keyName (keyBin), "user:/binary/foo");
+	succeed_if (keyCopy (keyNorm, keyBin, KEY_CP_NAME) != NULL, "could not copy name to binary key");
+	succeed_if_same_string (keyName (keyNorm), "user:/binary/foo");
+	succeed_if_same_string (keyName (keyBin), "user:/binary/foo");
+
+	keyDel (keyNorm);
+	keyDel (keyLock);
+	keyDel (keyBin);
+
+	Key * keyValSource = keyNew ("user:/hello", KEY_VALUE, "hello", KEY_END);
+	Key * keyValDest = keyNew ("user:/hi", KEY_END);
+	keyValDest = keyCopy (keyValDest, keyValSource, KEY_CP_ALL);
+	compare_key (keyValDest, keyValSource);
+
+	keySetString (keyValSource, "This string has special chars \n \\ \t \a");
+	keySetName (keyValDest, "user:/hi");
+	keyValDest = keyCopy (keyValDest, keyValSource, KEY_CP_ALL);
+	succeed_if_same_string (keyString (keyValDest), keyString (keyValSource));
+	compare_key (keyValDest, keyValSource);
+
+	keySetString (keyValSource, "This string has special \0 here");
+	keySetName (keyValDest, "user:/hi");
+	keyValDest = keyCopy (keyValDest, keyValSource, KEY_CP_ALL);
+	succeed_if_same_string (keyString (keyValDest), keyString (keyValSource));
+	compare_key (keyValDest, keyValSource);
+
+	keyDel (keyValSource);
+	keyDel (keyValDest);
 }
 
 static void test_keyFixedNew (void)
@@ -1187,7 +1225,6 @@ int main (int argc, char ** argv)
 	test_keyRefcounter ();
 	test_keyHelpers ();
 	test_keyPlugin ();
-	test_keyCompare ();
 	test_keyNewExtensions ();
 	test_keyComment ();
 	test_keyLock ();
